"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const backfill = __importStar(require("backfill/lib/api"));
const path_1 = __importDefault(require("path"));
const cacheConfig_1 = require("./cacheConfig");
const npmlog_1 = __importDefault(require("npmlog"));
const hashes = {};
const cacheHits = {};
exports.cacheHits = cacheHits;
async function computeHash(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const name = info.name;
    logger.setName(name);
    try {
        const hash = await backfill.computeHash(packagePath, logger, context.command.join(" ") + context.args.join(" "), cacheConfig);
        hashes[info.name] = hash;
    }
    catch (e) {
        npmlog_1.default.error(`${info.name} computeHash`, e);
    }
}
exports.computeHash = computeHash;
async function fetchBackfill(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const hash = hashes[info.name];
    try {
        const cacheHit = await backfill.fetch(packagePath, hash, logger, cacheConfig);
        cacheHits[info.name] = cacheHit;
    }
    catch (e) {
        npmlog_1.default.error(`${info.name} fetchBackfill`, e);
    }
}
exports.fetchBackfill = fetchBackfill;
async function putBackfill(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const hash = hashes[info.name];
    try {
        await backfill.put(packagePath, hash, logger, cacheConfig);
    }
    catch (e) {
        // sometimes outputGlob don't match any files, so skipping this
    }
}
exports.putBackfill = putBackfill;
