"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const workspace_tools_1 = require("workspace-tools");
const os_1 = __importDefault(require("os"));
const p_profiler_1 = __importDefault(require("p-profiler"));
const p_queue_1 = __importDefault(require("p-queue"));
const args_1 = require("./args");
const events_1 = require("events");
function createContext(options) {
    const { root, parsedArgs, configResults } = options;
    const concurrency = os_1.default.cpus().length - 1;
    const command = parsedArgs._;
    return {
        root,
        cacheOptions: (configResults === null || configResults === void 0 ? void 0 : configResults.config.cacheOptions) || {},
        allPackages: workspace_tools_1.getPackageInfos(root),
        command,
        concurrency: parsedArgs.concurrency || (configResults === null || configResults === void 0 ? void 0 : configResults.config.concurrency) ||
            concurrency,
        pipeline: (configResults === null || configResults === void 0 ? void 0 : configResults.config.pipeline) || {
            build: ["^build"],
            clean: [],
        },
        taskDepsGraph: [],
        tasks: new Map(),
        since: parsedArgs.since || undefined,
        ignore: parsedArgs.ignore || (configResults === null || configResults === void 0 ? void 0 : configResults.config.ignoreGlob) || [],
        deps: parsedArgs.deps || (configResults === null || configResults === void 0 ? void 0 : configResults.config.deps) || false,
        scope: parsedArgs.scope || (configResults === null || configResults === void 0 ? void 0 : configResults.config.scope) || [],
        measures: {
            start: [0, 0],
            duration: [0, 0],
            taskStats: [],
            failedTask: undefined,
        },
        profiler: new p_profiler_1.default({
            concurrency,
            prefix: "lage",
            outDir: process.cwd(),
        }),
        taskLogs: new Map(),
        queue: new p_queue_1.default({ concurrency }),
        cache: parsedArgs.cache === false ? false : true,
        node: parsedArgs.node ? args_1.arrifyArgs(parsedArgs.node) : [],
        args: args_1.getPassThroughArgs(parsedArgs),
        events: new events_1.EventEmitter(),
        verbose: parsedArgs.verbose,
        profile: parsedArgs.profile,
    };
}
exports.createContext = createContext;
