"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cosmiconfig_1 = require("cosmiconfig");
const discoverTaskDeps_1 = require("./task/discoverTaskDeps");
const workspace_tools_1 = require("workspace-tools");
const logger_1 = require("./logger");
const taskRunner_1 = require("./task/taskRunner");
const npmlog_1 = __importDefault(require("npmlog"));
const args_1 = require("./args");
const context_1 = require("./context");
const abortSignal_1 = require("./task/abortSignal");
console.log(`🧱 Lage task runner 🧱`);
console.log(``);
// Verify presence of git
const root = workspace_tools_1.findGitRoot(process.cwd());
if (!root) {
    throw new Error("This must be called inside a git-controlled repo");
}
// Search for lage.config.js file
const ConfigModuleName = "lage";
const configResults = cosmiconfig_1.cosmiconfigSync(ConfigModuleName).search(root || process.cwd());
// Parse CLI args
const parsedArgs = args_1.parseArgs();
args_1.validateInput(parsedArgs);
// Create context
const context = context_1.createContext({ parsedArgs, root, configResults });
// Initialize logger
logger_1.initLogger(context);
if (context.verbose) {
    npmlog_1.default.level = "verbose";
}
discoverTaskDeps_1.discoverTaskDeps(context);
// Hush leaky event listeners (# of tasks = # of abort listeners)
abortSignal_1.setMaxEventListeners(context);
(async () => {
    await taskRunner_1.runTasks(context);
})();
