"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const npmlog_1 = __importDefault(require("npmlog"));
const taskId_1 = require("../task/taskId");
const stream_1 = require("stream");
const chalk_1 = __importDefault(require("chalk"));
let _context;
function initLogger(context) {
    _context = context;
}
exports.initLogger = initLogger;
function getTaskLogPrefix(taskId) {
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    return `${pkg} ${chalk_1.default.green(task)}`;
}
exports.getTaskLogPrefix = getTaskLogPrefix;
function addToTaskLog(taskId, message) {
    var _a;
    const { taskLogs } = _context;
    if (!taskLogs.has(taskId)) {
        taskLogs.set(taskId, []);
    }
    (_a = taskLogs.get(taskId)) === null || _a === void 0 ? void 0 : _a.push(message);
}
function info(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.info(getTaskLogPrefix(taskId), chalk_1.default.cyan(message), ...args);
}
exports.info = info;
function warn(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.warns(getTaskLogPrefix(taskId), chalk_1.default.yellow(message), ...args);
}
exports.warn = warn;
function error(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.error(getTaskLogPrefix(taskId), chalk_1.default.red(message), ...args);
}
exports.error = error;
function verbose(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.verbose(getTaskLogPrefix(taskId), chalk_1.default.underline(message), ...args);
}
exports.verbose = verbose;
class NpmLogWritable extends stream_1.Writable {
    constructor(taskId) {
        super();
        this.taskId = taskId;
        this.buffer = "";
    }
    _write(chunk, encoding, callback) {
        let prev = 0;
        let curr = 0;
        while (curr < chunk.byteLength) {
            if (chunk[curr] === 13 || (chunk[curr] === 10 && curr - prev > 1)) {
                this.buffer =
                    this.buffer +
                        chunk
                            .slice(prev, curr)
                            .toString()
                            .trim();
                addToTaskLog(this.taskId, this.buffer);
                npmlog_1.default.verbose(getTaskLogPrefix(this.taskId), this.buffer);
                this.buffer = "";
                prev = curr;
            }
            curr++;
        }
        callback();
    }
}
exports.NpmLogWritable = NpmLogWritable;
exports.default = { info, warn, error, verbose };
