"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const taskId_1 = require("../task/taskId");
const npmlog_1 = __importDefault(require("npmlog"));
const chalk_1 = __importDefault(require("chalk"));
const formatDuration_1 = require("./formatDuration");
const index_1 = require("./index");
function hr() {
    npmlog_1.default.info("", "----------------------------------------------");
}
async function reportSummary(context) {
    const { measures, taskLogs } = context;
    const statusColorFn = {
        success: chalk_1.default.greenBright,
        failed: chalk_1.default.redBright,
        skipped: chalk_1.default.gray,
    };
    hr();
    npmlog_1.default.info("", chalk_1.default.cyanBright(`🏗 Summary\n`));
    if (measures.failedTask) {
        const [pkg, task] = taskId_1.getPackageTaskFromId(measures.failedTask);
        npmlog_1.default.error("", `ERROR DETECTED IN ${pkg} ${task}`);
        npmlog_1.default.error("", taskLogs.get(measures.failedTask).join("\n"));
        hr();
    }
    if (measures.taskStats.length > 0) {
        for (const stats of measures.taskStats) {
            const colorFn = statusColorFn[stats.status];
            index_1.info(stats.taskId, colorFn(`${stats.status}, took ${formatDuration_1.formatDuration(stats.duration)}`));
        }
    }
    else {
        npmlog_1.default.info("", "Nothing has been run.");
    }
    hr();
    npmlog_1.default.info("", `Took a total of ${formatDuration_1.formatDuration(measures.duration)} to complete`);
}
exports.reportSummary = reportSummary;
