"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const taskId_1 = require("./taskId");
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const logger_1 = __importStar(require("../logger"));
const taskWrapper_1 = require("./taskWrapper");
const abortSignal_1 = require("./abortSignal");
const os_1 = __importDefault(require("os"));
function npmTask(taskId, context) {
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    const { allPackages, queue } = context;
    const npmCmd = path_1.default.join(path_1.default.dirname(process.execPath), os_1.default.platform() === "win32" ? "npm.cmd" : "npm");
    const npmArgs = [...context.node, "run", task, "--", ...context.args];
    return queue.add(() => taskWrapper_1.taskWrapper(taskId, () => new Promise((resolve, reject) => {
        if (!allPackages[pkg].scripts || !allPackages[pkg].scripts[task]) {
            logger_1.default.info(taskId, `Empty script detected, skipping`);
            return resolve();
        }
        logger_1.default.verbose(taskId, `Running ${[npmCmd, ...npmArgs].join(" ")}`);
        const cp = child_process_1.spawn(npmCmd, npmArgs, {
            cwd: path_1.default.dirname(allPackages[pkg].packageJsonPath),
            stdio: "pipe",
        });
        context.events.once("abort", terminate);
        const stdoutLogger = new logger_1.NpmLogWritable(taskId);
        cp.stdout.pipe(stdoutLogger);
        const stderrLogger = new logger_1.NpmLogWritable(taskId);
        cp.stderr.pipe(stderrLogger);
        cp.on("exit", (code) => {
            context.events.off("off", terminate);
            if (code === 0) {
                return resolve();
            }
            context.measures.failedTask = taskId;
            abortSignal_1.abort(context);
            reject();
        });
        function terminate() {
            queue.pause();
            queue.clear();
            cp.kill("SIGKILL");
        }
    }), context));
}
exports.npmTask = npmTask;
