"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const p_graph_1 = __importDefault(require("p-graph"));
const cacheTasks_1 = require("../cache/cacheTasks");
const reportSummary_1 = require("../logger/reportSummary");
const npmlog_1 = __importDefault(require("npmlog"));
async function runTasks(context) {
    const { profiler } = context;
    context.measures.start = process.hrtime();
    cacheTasks_1.generateCacheTasks(context);
    try {
        await p_graph_1.default(context.tasks, context.taskDepsGraph).run();
    }
    catch (_a) {
        // passthru - we always want to print out the summary ourselves
    }
    if (context.profile) {
        const profileFile = profiler.output();
        npmlog_1.default.info("runTasks", `Profile saved to ${profileFile}`);
    }
    context.measures.duration = process.hrtime(context.measures.start);
    await reportSummary_1.reportSummary(context);
    if (context.measures.failedTask) {
        process.exit(1);
    }
}
exports.runTasks = runTasks;
