"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const taskId_1 = require("./taskId");
const backfill_1 = require("../cache/backfill");
const logger_1 = require("../logger");
const cacheTasks_1 = require("../cache/cacheTasks");
const formatDuration_1 = require("../logger/formatDuration");
async function taskWrapper(taskId, fn, context) {
    const { allPackages, profiler, measures, queue } = context;
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    const start = process.hrtime();
    if (!backfill_1.cacheHits[pkg]) {
        if (!cacheTasks_1.isCacheTask(task)) {
            logger_1.info(taskId, "started");
        }
        try {
            await profiler.run(() => fn(allPackages[pkg], context), taskId);
            const duration = process.hrtime(start);
            if (!cacheTasks_1.isCacheTask(task)) {
                measures.taskStats.push({ taskId, start, duration, status: "success" });
                logger_1.info(taskId, `done - took ${formatDuration_1.formatDuration(duration)}`);
            }
        }
        catch (e) {
            const duration = process.hrtime(start);
            measures.taskStats.push({ taskId, start, duration, status: "failed" });
            throw e;
        }
    }
    else if (!cacheTasks_1.isCacheTask(task)) {
        const duration = process.hrtime(start);
        measures.taskStats.push({ taskId, start, duration, status: "skipped" });
        logger_1.info(taskId, "skipped");
    }
}
exports.taskWrapper = taskWrapper;
